@@ -744,10 +744,18 @@ class DaemonContext_make_signal_handler_TestCase(DaemonContext_BaseTestCase):
         result = instance._make_signal_handler(target)
         self.assertEqual(expected_result, result)
 
-    def test_returns_method_for_name(self):
-        """ Should return method of DaemonContext when name specified. """
+    def test_returns_method_for_str_name(self):
+        """ Should return DaemonContext method for name of type ‘str’. """
         instance = self.test_instance
-        target = 'terminate'
+        target = str('terminate')
+        expected_result = instance.terminate
+        result = instance._make_signal_handler(target)
+        self.assertEqual(expected_result, result)
+
+    def test_returns_method_for_unicode_name(self):
+        """ Should return DaemonContext method for name of type ‘unicode’. """
+        instance = self.test_instance
+        target = unicode('terminate')
         expected_result = instance.terminate
         result = instance._make_signal_handler(target)
         self.assertEqual(expected_result, result)
@@ -1011,9 +1019,14 @@ class change_process_owner_TestCase(scaffold.TestCase):
 
             """
         args = self.test_args
+        mock_os_module = mock.MagicMock()
+        mock_os_module.attach_mock(mock_func_os_setuid, "setuid")
+        mock_os_module.attach_mock(mock_func_os_setgid, "setgid")
         daemon.daemon.change_process_owner(**args)
-        mock_func_os_setuid.assert_called()
-        mock_func_os_setgid.assert_called()
+        mock_os_module.assert_has_calls([
+                mock.call.setgid(mock.ANY),
+                mock.call.setuid(mock.ANY),
+                ])
 
     def test_changes_group_id_to_gid(
             self,
@@ -1022,7 +1035,7 @@ class change_process_owner_TestCase(scaffold.TestCase):
         args = self.test_args
         gid = self.test_gid
         daemon.daemon.change_process_owner(**args)
-        mock_func_os_setgid.assert_called(gid)
+        mock_func_os_setgid.assert_called_once_with(gid)
 
     def test_changes_user_id_to_uid(
             self,
@@ -1031,7 +1044,7 @@ class change_process_owner_TestCase(scaffold.TestCase):
         args = self.test_args
         uid = self.test_uid
         daemon.daemon.change_process_owner(**args)
-        mock_func_os_setuid.assert_called(uid)
+        mock_func_os_setuid.assert_called_once_with(uid)
 
     def test_raises_daemon_error_on_os_error_from_setgid(
             self,
